@@ -133,7 +133,7 @@ def tokenize_tweets(data):
 		sample_data_tokenized.append(tokenizer.tokenize(tweets.lower()))
 	return sample_data_tokenized
 	
-def keywords_score(data,sample_data_tokenized, keyword_corpus):
+def keyword_score(data,sample_data_tokenized, keyword_corpus):
 	scores = []
 	for i in range(len(sample_data_tokenized)):
 		score=0
@@ -160,7 +160,7 @@ def hashtag_score(data, sample_data_tokenized, hashtag_corpus):
 			scores.append(score)
 		except ZeroDivisionError:
 			scores.append(0)
-	data['hashtags_score'] = scores
+	data['hashtag_score'] = scores
 	data['index'] = [i for i in range(len(data))]
 	data['names']= ['TWEET '+str(i) for i in range(len(data))]
 	return data	
@@ -958,12 +958,14 @@ def NLP_analysis(data, keyword_corpus, hashtag_corpus):
 	tweets_df = hashtag_score(tweets_df, sample_data_tokenized,hashtag_corpus)	
 	tweets_df["terrorist_suggestion"] = 0
 	tweets_df["terrorist_suggestion"][(tweets_df["hashtag_score"]>0) | (tweets_df["keyword_score"]>0)] = 1
-	data["per_hash_key"] = len(tweets_df[tweets_df["terrorist_suggestion"]==1]) / len(tweets_df[tweets_df["terrorist_suggestion"]==0])
+	data["per_hash_key"] = len(tweets_df[tweets_df["terrorist_suggestion"]==1]) / len(tweets_df)
 	tweets_df["terrorist_suggestion"][(tweets_df["terrorist_suggestion"]==1) & (tweets_df["polarity"] < -0.1) & (tweets_df["subjectivity"]>0.6)]= 2
 	data["per_terr_hash_key"] = len(tweets_df[tweets_df["terrorist_suggestion"]==2]) / len(tweets_df[tweets_df["terrorist_suggestion"]==1])
 	data["suggestion"] = "No terrorist"
-	data["suggestion"][((data["per_terr_hash_key"] >0.7) & (data["per_hash_key"]>0.15))] = "Terrorist"
-	
+	print(data[["per_terr_hash_key","per_hash_key","suggestion"]])
+	print(data)
+	data["suggestion"][(data["per_terr_hash_key"] >0.7) & (data["per_hash_key"]>0.15)] = "Terrorist"
+	print(data)
 	return data,tweets_df
 	
 def more_tweets_required(df,consumerKey,consumerSecret,accessToken,accessTokenSecret):
